/*
 * Author: Daniel Pavel <daniel.pavel@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *   * Neither the name of the Softwin nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package sk.lacike.ntlm;

import java.security.Principal;
import java.util.HashMap;

import com.atlassian.core.util.RandomGenerator;
import com.atlassian.seraph.auth.DefaultAuthenticator;
import com.atlassian.seraph.config.SecurityConfig;

/**
 * "Funny" authenticator: allow any authentication with the proper password -- our own.
 * If you need your custom authenticator to allow NTLM-authenticated users enter JIRA silently,
 * you should check for password identity (==, not equals() !) with the NO_PASSWORD field.
 * 
 * This class is only used when your JIRA configuration uses the DefaultAuthenticator (see
 * seraph-config.xml).  If you're using some other authenticator, and want to use NTLM,
 * you should modify it to do something similar to what this one is doing.
 */
public class BypassDefaultAuthenticator extends DefaultAuthenticator {
	public static final long serialVersionUID = 0x20050803;

	public static final String NO_PASSWORD = RandomGenerator.randomString(256); // just for kicks

	public BypassDefaultAuthenticator(final SecurityConfig _security) {
		super();

		// hope this works
		init(new HashMap(), _security);
	}

	protected boolean authenticate(final Principal _user, final String _password) {
		// ********* WARNING ***********
		// use "==" not equals() !!!
		if (_password == NO_PASSWORD) {
			return true;
		}
		if (_password.equals(NO_PASSWORD)) {
			return false;
		}

		return super.authenticate(_user, _password);
	}
}
