package sk.lacike.ntlm.jespa.jira;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

import org.apache.log4j.Category;

import sk.lacike.jira.JiraComponentManager;

import jespa.http.HttpSecurityService;
import jespa.security.SecurityProviderException;

public class NTLMLoginFilter extends HttpSecurityService implements Filter {

	public static final String CONFIG_FILE = "ntlm4atlassian";
	public static final String JESPA_CONFIG_DOMAIN = "jespa.bindstr";
	public static final String JESPA_CONFIG_USERNAME = "jespa.service.acctname";
	public static final String JESPA_CONFIG_PASSWORD = "jespa.service.password";
	public static final String JESPA_CONFIG_FALLBACK = "jespa.fallback.location";
	public static final String JESPA_CONFIG_LOG_LEVEL = "jespa.log.level";
	public static final String JESPA_CONFIG_LOG_PATH = "jespa.log.path";

	private static final Category LOG = Category.getInstance(NTLMLoginFilter.class);
	
	private boolean isEnabled = true;
//	private String fallback = null;

	public void init(FilterConfig config) throws ServletException
    {
		// read configuration file
		LOG.info("Loading Jespa NTLM configuration");
		JiraComponentManager.getPropertyLoader().loadDefault(CONFIG_FILE, this.getClass());
		
		// provide the JESPA parent class only the necessary configuration
    	Map properties = new HashMap();
    	properties.put(JESPA_CONFIG_DOMAIN, JiraComponentManager.getPropertyLoader().readDefault(this.getClass(), JESPA_CONFIG_DOMAIN));
		properties.put(JESPA_CONFIG_USERNAME, JiraComponentManager.getPropertyLoader().readDefault(this.getClass(), JESPA_CONFIG_USERNAME));
		properties.put(JESPA_CONFIG_PASSWORD, JiraComponentManager.getPropertyLoader().readDefault(this.getClass(), JESPA_CONFIG_PASSWORD));
		properties.put(JESPA_CONFIG_FALLBACK, JiraComponentManager.getPropertyLoader().readDefault(this.getClass(), JESPA_CONFIG_FALLBACK));
		properties.put(JESPA_CONFIG_LOG_LEVEL, JiraComponentManager.getPropertyLoader().readDefault(this.getClass(), JESPA_CONFIG_LOG_LEVEL));
		properties.put(JESPA_CONFIG_LOG_PATH, JiraComponentManager.getPropertyLoader().readDefault(this.getClass(), JESPA_CONFIG_LOG_PATH));
		
        try {
    		LOG.info("Initializing Jespa NTLM");
			super.init(properties);
			LOG.info("Jespa NTLM initialized");
		} catch (SecurityProviderException e) {
			LOG.error("Unable to initialize JESPA Filter!", e);
			isEnabled = false;
		}
    }
	
    public void doFilter(ServletRequest request,
            ServletResponse response,
            FilterChain chain) throws IOException, ServletException
    {
        /* This illustrates how to bypass or disable the HttpSecurityService
         * entirely. This might be useful if, for example, you wanted another
         * filter in the chain to assume responsibility of securing your application.
         *
         * The condition used to determine if the HttpSecurityService should be
         * invoked could be anything including a regex of the requested object,
         * a database query, etc (although one should make sure it is not something
         * that can be supplied by the client as that would be a security
         * vulnerability).
         */
        if (!isEnabled) {
            chain.doFilter(request, response);
        } else {
            super.doFilter(request, response, chain);
        }
    }
	
	
    public void destroy()
    {
    }
}
